# assumes you have the jar already loaded in the classpath

java_import 'com.rockset.client.RocksetClient'
java_import 'com.rockset.client.model.AddDocumentsRequest'
java_import 'com.rockset.client.model.CreateCollectionRequest'
java_import 'com.rockset.client.model.QueryRequest'
java_import 'com.rockset.client.model.QueryRequestSql'

require_relative 'rockset/version'

module Rockset
  class DB
    attr_reader :rockset_client, :model

    # alias_method :insert, :create_document
    # alias_method :create_table, :create_collection

    def initialize(apikey, apiserver = 'api.rs2.usw2.rockset.com')
      @rockset_client = RocksetClient.new apikey, apiserver
    end

    def query(query_str)
      query_request = QueryRequest.new
      query_sql = QueryRequestSql.new.query(query_str)
      req = query_request.sql(query_sql)
      res = rockset_obj.query req
      res.get_results.to_a
    end

    def create_document(collection, values, workspace = 'commons')
      docs = create_doc_request(values)
      rockset_obj.addDocuments(workspace, collection, docs)
    end

    def create_collection(collection_name, workspace = 'commons')
      collection = create_collection_request(collection_name)
      rockset_obj.create_collection(workspace, collection)
    end

    private

    def rockset_obj
      @rockset_client ||= create_client
    end

    def create_doc_request(values)
      add_doc_req = AddDocumentsRequest.new
      add_doc_req.data(values)
    end

    def create_collection_request(value)
      collection_req = CreateCollectionRequest.new
      collection_req.name(value)
    end
  end
end
